# Copyright 2023 Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from odoo import _, fields, models
from odoo.exceptions import UserError


class ApiBackend(models.AbstractModel):
    _name = "api.backend"
    _description = "API Backend"
    _restrict_backend = False

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    name = fields.Char(required=True)
    url = fields.Char("URL", required=True)
    ssl = fields.Boolean("SSL connection", default=True)
    timeout = fields.Integer(default=15)
    auth_type = fields.Selection(
        selection=[
            ("none", "None"),
            ("user", "User or API keys"),
            ("key", "API key"),
        ],
        string="Authentication type",
        default="none",
        required=True,
    )
    login = fields.Char("Username / Client ID")
    password = fields.Char("Password / Client Secret")
    api_key = fields.Char("API Key")
    active = fields.Boolean("Actif", default=False)

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Inherit parent
    # ------------------------------------------------------
    def action_unarchive(self):
        if self._restrict_backend:
            if len(self) > 1:
                raise UserError(
                    _("It is not possible to active more than one backend.")
                )
            else:
                super().action_unarchive()
                return self.search([("id", "!=", self.id)]).action_archive()
        else:
            return super().action_unarchive()

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
