# Copyright 2023 Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)
from datetime import date, datetime

import pytz

from odoo import _, fields
from odoo.exceptions import ValidationError


def local_to_utc(dt, timezone):
    """
    Returns UTC datetime without timezone from local datetime without timezone
    :param datetime or date or string dt: local datetime without timezone to convert
    :param string timezone: local timezone
    @returns datetime: UTC datetime without timezone
    """
    if isinstance(dt, str):
        dt = fields.Datetime().from_string(dt)
    elif isinstance(dt, date):
        dt = fields.Datetime().to_datetime(dt)
    elif not isinstance(dt, datetime):
        raise ValidationError(_("La valeur passée en paramètre n'est pas reconnue"))

    return (
        pytz.timezone(timezone).localize(dt).astimezone(pytz.UTC).replace(tzinfo=None)
    )


def utc_to_local(dt, timezone):
    """
    Returns local datetime without timezone from UTC datetime without timezone
    :param datetime or date or string dt: UTC datetime without timezone to convert
    :param string timezone: local timezone
    @returns datetime: local datetime without timezone
    """
    if isinstance(dt, str):
        dt = fields.Datetime().from_string(dt)
    elif isinstance(dt, date):
        dt = fields.Datetime().to_datetime(dt)
    elif not isinstance(dt, datetime):
        raise ValidationError(_("La valeur passée en paramètre n'est pas reconnue"))

    return (
        pytz.UTC.localize(dt).astimezone(pytz.timezone(timezone)).replace(tzinfo=None)
    )
